# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-08-31 13:50
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import translations.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Code',
            fields=[
                ('id', models.CharField(default=translations.models.generate_code, max_length=12, primary_key=True, serialize=False, verbose_name='id')),
            ],
            options={
                'verbose_name': 'code',
                'verbose_name_plural': 'codes',
            },
        ),
        migrations.CreateModel(
            name='LongTranslationString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[(b'en', 'English'), (b'de', 'German'), (b'jp', 'Japanese'), (b'cn', 'Chinese')], max_length=8, verbose_name='language')),
                ('string', models.CharField(max_length=256, verbose_name='string')),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='long_translation_strings', to='translations.Code', verbose_name='code')),
            ],
            options={
                'verbose_name': 'long translation string',
                'verbose_name_plural': 'long translation strings',
            },
        ),
        migrations.CreateModel(
            name='MediumTranslationString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[(b'en', 'English'), (b'de', 'German'), (b'jp', 'Japanese'), (b'cn', 'Chinese')], max_length=8, verbose_name='language')),
                ('string', models.CharField(max_length=64, verbose_name='string')),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='medium_translation_strings', to='translations.Code', verbose_name='code')),
            ],
            options={
                'verbose_name': 'medium translation string',
                'verbose_name_plural': 'medium translation strings',
            },
        ),
        migrations.CreateModel(
            name='ShortTranslationString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[(b'en', 'English'), (b'de', 'German'), (b'jp', 'Japanese'), (b'cn', 'Chinese')], max_length=8, verbose_name='language')),
                ('string', models.CharField(max_length=16, verbose_name='string')),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='short_translation_strings', to='translations.Code', verbose_name='code')),
            ],
            options={
                'verbose_name': 'short translation string',
                'verbose_name_plural': 'short translation strings',
            },
        ),
        migrations.CreateModel(
            name='TextTranslationString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[(b'en', 'English'), (b'de', 'German'), (b'jp', 'Japanese'), (b'cn', 'Chinese')], max_length=8, verbose_name='language')),
                ('string', models.TextField(verbose_name='string')),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='text_translation_strings', to='translations.Code', verbose_name='code')),
            ],
            options={
                'verbose_name': 'text translation string',
                'verbose_name_plural': 'text translation strings',
            },
        ),
        migrations.CreateModel(
            name='VeryLongTranslationString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[(b'en', 'English'), (b'de', 'German'), (b'jp', 'Japanese'), (b'cn', 'Chinese')], max_length=8, verbose_name='language')),
                ('string', models.CharField(max_length=1024, verbose_name='string')),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='very_long_translation_strings', to='translations.Code', verbose_name='code')),
            ],
            options={
                'verbose_name': 'very long translation string',
                'verbose_name_plural': 'very long translation strings',
            },
        ),
        migrations.CreateModel(
            name='VeryShortTranslationString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', models.CharField(choices=[(b'en', 'English'), (b'de', 'German'), (b'jp', 'Japanese'), (b'cn', 'Chinese')], max_length=8, verbose_name='language')),
                ('string', models.CharField(max_length=16, verbose_name='string')),
                ('code', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='very_short_translation_strings', to='translations.Code', verbose_name='code')),
            ],
            options={
                'verbose_name': 'very short translation string',
                'verbose_name_plural': 'very short translation strings',
            },
        ),
        migrations.AlterUniqueTogether(
            name='veryshorttranslationstring',
            unique_together=set([('code', 'language')]),
        ),
        migrations.AlterUniqueTogether(
            name='verylongtranslationstring',
            unique_together=set([('code', 'language')]),
        ),
        migrations.AlterUniqueTogether(
            name='texttranslationstring',
            unique_together=set([('code', 'language')]),
        ),
        migrations.AlterUniqueTogether(
            name='shorttranslationstring',
            unique_together=set([('code', 'language')]),
        ),
        migrations.AlterUniqueTogether(
            name='mediumtranslationstring',
            unique_together=set([('code', 'language')]),
        ),
        migrations.AlterUniqueTogether(
            name='longtranslationstring',
            unique_together=set([('code', 'language')]),
        ),
    ]
